@@ -1,8 +1,3 @@
-#' @export
-degrees_of_freedom.coeftest <- function(model, ...) {
-  attributes(model)$df
-}
-
 #' @export
 ci.coeftest <- ci.default
 
@@ -22,5 +17,6 @@ standard_error.coeftest <- function(model, ...) {
   )
 }
 
+#' @rdname model_parameters.htest
 #' @export
 model_parameters.coeftest <- model_parameters.ivFixed
