@@ -14,11 +14,19 @@
 #' one or more of these lines by providing a names vector, where the to be
 #' highlighted values should be named `"emph"`, e.g
 #' `ci_levels = c(0.25, 0.5, emph = 0.95)`.
+#' @param x An object returned by [`model_parameters()`][model_parameters].
+#' @param digits Number of digits for rounding or significant figures. May also
+#' be `"signif"` to return significant figures or `"scientific"` to return
+#' scientific notation. Control the number of digits by adding the value as
+#' suffix, e.g. `digits = "scientific4"` to have scientific notation with 4
+#' decimal places, or `digits = "signif5"` for 5 significant figures (see also
+#' [signif()]).
 #'
 #' @inheritParams model_parameters
 #' @inheritParams model_parameters.default
 #' @inheritParams model_parameters.glmmTMB
 #' @inheritParams standard_error
+#' @inheritParams print.parameters_model
 #'
 #' @note
 #' Curently, `p_function()` computes intervals based on Wald t- or z-statistic.
@@ -381,6 +389,7 @@ plot.parameters_p_function <- function(x, ...) {
 }
 
 
+#' @rdname p_function
 #' @export
 format.parameters_p_function <- function(x,
                                          digits = 2,
@@ -416,6 +425,7 @@ format.parameters_p_function <- function(x,
 }
 
 
+#' @rdname p_function
 #' @export
 print.parameters_p_function <- function(x,
                                         digits = 2,
@@ -435,28 +445,6 @@ print.parameters_p_function <- function(x,
 }
 
 
-#' @export
-print_md.parameters_p_function <- function(x,
-                                           digits = 2,
-                                           ci_width = "auto",
-                                           ci_brackets = c("(", ")"),
-                                           pretty_names = TRUE,
-                                           ...) {
-  .print_p_function(x, digits, ci_width, ci_brackets, pretty_names, format = "markdown", ...)
-}
-
-
-#' @export
-print_html.parameters_p_function <- function(x,
-                                             digits = 2,
-                                             ci_width = "auto",
-                                             ci_brackets = c("(", ")"),
-                                             pretty_names = TRUE,
-                                             ...) {
-  .print_p_function(x, digits, ci_width, ci_brackets, pretty_names, format = "html", ...)
-}
-
-
 # helper ----------
 
 .print_p_function <- function(x,
@@ -466,6 +454,9 @@ print_html.parameters_p_function <- function(x,
                               pretty_names = TRUE,
                               format = "html",
                               ...) {
+  # which engine?
+  engine <- .check_format_backend(...)
+
   formatted_table <- format(
     x,
     digits = digits,
@@ -476,6 +467,11 @@ print_html.parameters_p_function <- function(x,
     ...
   )
 
+  # set engine for html format
+  if (format == "html" && identical(engine, "tt")) {
+    format <- "tt"
+  }
+
   insight::export_table(
     formatted_table,
     format = format,
